Models
======

Data models used throughout fbchat-muqit.

.. toctree::
   :maxdepth: 1

   thread
   message
   messageData
   user
   attachment
   thread_actions
   timestamps
   typing
   presence
   notifications
   themes

Overview
--------

.. autosummary::
   :toctree: generated

   fbchat_muqit.Thread
   fbchat_muqit.Message
   fbchat_muqit.User
   fbchat_muqit.ImageAttachment
